%bcond docs 1

Name:           libipuz
Version:        0.4.7
Release:        1.20240606215454797966.master.131.g76ac0e0%{?dist}
Summary:        Library for parsing .ipuz puzzle files

License:        LGPL-2.1-or-later OR MIT
URL:            https://gitlab.gnome.org/jrb/libipuz
Source:         libipuz-0.4.7.tar.gz

# Ensure we only enable introspection support from 0.4.7 onwards
%bcond introspection %([ $(echo %{version} | tr -d .) -eq 047 ] && echo 1 || echo 0)

BuildRequires:  cargo-rpm-macros >= 24
BuildRequires:  gcc
BuildRequires:  gettext
BuildRequires:  meson
BuildRequires:  python3
BuildRequires:  sed
%if %{with docs}
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(sphinx-rtd-theme)
BuildRequires:  python3dist(myst-parser)
%endif

BuildRequires:  glib2-devel
BuildRequires:  json-glib-devel
%if %{with introspection}
BuildRequires:  gi-docgen
BuildRequires:  gobject-introspection-devel
%endif

%description
This is a library for parsing .ipuz puzzle files, for crossword puzzles,
sudokus, etc. The library only handles crosswords for now.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
%if %{with docs}
Suggests:       %{name}-doc = %{version}-%{release}
%endif

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%if %{with docs}
%package        doc
Summary:        Documentation for %{name}
BuildArch:      noarch

%description    doc
This package contains additional documentation for %{name}.
%endif

%package        tests
Summary:        Tests for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    tests
The %{name}-tests package contains tests for %{name}.

%prep
%autosetup -p1 -n libipuz-0.4.7
%cargo_prep

# Drop version locks
rm libipuz/rust/Cargo.lock
sed -i '/Cargo.lock/d' libipuz/rust/meson.build

%generate_buildrequires
cd libipuz/rust
%cargo_generate_buildrequires

%build
%meson
%meson_build

%if %{with docs}
sphinx-build-3 docs html
rm -rf html/.{doctrees,buildinfo}
%endif

%install
%meson_install

%check
%meson_test

%files
%license LICENSE COPYING.LGPL COPYING.MIT
%doc README.md NEWS.md
%{_libdir}/lib%{name}-0.4.so

%files devel
%{_includedir}/*
%if %{with introspection}
%{_datadir}/gir-1.0/Ipuz-1.0.gir
%{_libdir}/girepository-1.0/Ipuz-1.0.typelib
%endif
%{_libdir}/pkgconfig/%{name}-0.4.pc

%if %{with docs}
%files doc
%license LICENSE COPYING.LGPL COPYING.MIT
%doc html
%if %{with introspection}
%doc %{_docdir}/%{name}-1.0/
%endif
%endif

%files tests
%dir %{_datadir}/installed-tests
%{_datadir}/installed-tests/%{name}-1.0
%dir %{_libexecdir}/installed-tests
%{_libexecdir}/installed-tests/%{name}-1.0

%changelog
* Thu Jun 06 2024 Packit <hello@packit.dev> - 0.4.7-1.20240606215454797966.master.131.g76ac0e0
- Clarify comment (Jonathan Blandford)
- Fix indentation (Jonathan Blandford)
- Hide some fields we don't use (Jonathan Blandford)
- Try an additional indent to see if admonitions can work correctly (Jonathan Blandford)
- Update intro description (Jonathan Blandford)
- let style_name be nullable (Jonathan Blandford)
- Fix mistake in text (Jonathan Blandford)
- include style docs (Jonathan Blandford)
- Clean up header (Jonathan Blandford)
- fix broken doc text (Jonathan Blandford)
- Add section header to IpuzStyle (Jonathan Blandford)
- Add params to example (Jonathan Blandford)
- Add enums to IpuzStyle (Jonathan Blandford)
- Update meson.build to replace deprecated features (Tanmay Patil)
- Missed two more cut-and-paste errors (Jonathan Blandford)
- Copied the default to the wrong string (Jonathan Blandford)
- Finished documenting IPuzPuzzle (Jonathan Blandford)
- Removed all instances of "@self: An #IpuzPuzzle" (Jonathan Blandford)
- Mark the whole struct as private. Nothing here should be exported (Jonathan Blandford)
- fix a typo (Jonathan Blandford)
- Add a section header for IpuzPuzzle (Jonathan Blandford)
- version should be readwrite, but construct only (Jonathan Blandford)
- Fix IPUZ_PUZZLE_ERROR quark (Jonathan Blandford)
- Quick side-quest to document IpuzPuzzleInfo (Jonathan Blandford)
- More documentation for IpuzPuzzle (Jonathan Blandford)
- Finish the annotations/documentation for the IpuzPuzzle properties (Jonathan Blandford)
- Seven more properties documented (Jonathan Blandford)
- Use org.libipuz namespace to declare "source" extension to ipuz (Tanmay Patil)
- Store the source string in .ipuz file (Tanmay Patil)
- Document the copyright and publisher properties fully (Jonathan Blandford)
- More work on documentation (Jonathan Blandford)
- Add getters/setters for most object properties (Jonathan Blandford)
- Fix memory leak (Tanmay Patil)
- Resolve rebase conflicts (Tanmay Patil)
- Add ipuz_acrostic_fix_source (Tanmay Patil)
- Update doc comments (Tanmay Patil)
- Refactor: replace all instances of *_str or *-string with only 'quote'/'source' (Tanmay Patil)
- Add source_str as a property to IPuzAcrostic (Tanmay Patil)
- fix comment typo (Jonathan Blandford)
- Make styles READABLE only for now (Jonathan Blandford)
- s/get_info/get_puzzle_info/ (Jonathan Blandford)
- Make ipuz_arrowword_foreach_blocks() consistent (Jonathan Blandford)
- Document IpuzCrosswordForeachClueFunc (Jonathan Blandford)
- Make IpuzPuzzleStyleForeach consistent (Jonathan Blandford)
- clean up enumeration text (Jonathan Blandford)
- Get the document reference right (Jonathan Blandford)
- Fix up the documentation (Jonathan Blandford)
- Actually make IpuzEnumerationForeachDelimFunc consistent (Jonathan Blandford)
- Make IpuzStyleForeachMarkFunc consistent with the rest (Jonathan Blandford)
- Remove debug print statements (Jonathan Blandford)
- Add doc comments to IpuzEnumerationForeachDelimFunc (Jonathan Blandford)
- Make IpuzEnumerationForeachDelimFunc consistant (Jonathan Blandford)
- Change CellCellType to CellType in the docs (Jonathan Blandford)
- Document IpuzCellType (Jonathan Blandford)
- Change IpuzCellCellType to just IpuzCellType (Jonathan Blandford)
- No longer safe to allocate IpuzCell's on the stack (Jonathan Blandford)
- Update the python example in the docs to work (Jonathan Blandford)
- Add transfer none to make get_clue_by_id() work (Jonathan Blandford)
- Add docs/annotations to get_cell() (Jonathan Blandford)
- Migrate cells to be ref counted. (Jonathan Blandford)
- Change IpuzClue from copy to refcounting (Jonathan Blandford)
- update libipuz page (Jonathan Blandford)
- Try and add a dependency on the build (Jonathan Blandford)
- Now let's try and include the reference correctly (Jonathan Blandford)
- Change gen-reference to be plausibly correct (Jonathan Blandford)
- Bump the BASE tag (Jonathan Blandford)
- Try manually including gi-docgen (Jonathan Blandford)
- Add a ref count (Jonathan Blandford)
- Add more dependencies (Jonathan Blandford)
- Include python deps for gi-gendoc (Jonathan Blandford)
- remove need of build (Jonathan Blandford)
- Missing a closed quote (Jonathan Blandford)
- Try to build and export the devel docs (Jonathan Blandford)
- Add docs/annotations to get_cell() (Jonathan Blandford)
- Set up a stub of an intro file (Jonathan Blandford)
- Add const to all the IpuzCellCoords passed in (Jonathan Blandford)
- Add doc comment to ipuz_symmetry_calculate (Jonathan Blandford)
- Change symmetry code to pass the coords by reference (Jonathan Blandford)
- Change IpuzArrowword to pass the coord by ref (Jonathan Blandford)
- Change IpuzGuesses to pass the coord by ref (Jonathan Blandford)
- Change IpuzBoard to pass coord by ref insted of by value (Jonathan Blandford)
- Change IpuzCellCoord args from value-> reference (Jonathan Blandford)
- Move from IpuzClueIds to pass by reference (Jonathan Blandford)
- remove proto for get_offset_coord() (Jonathan Blandford)
- Change get_clue_id to get_id_by_clue (Jonathan Blandford)
- Chain up to the parent class in finalize (Jonathan Blandford)
- Update the fedora requirements (Jonathan Blandford)
- merge the two meson options files (Jonathan Blandford)
- Add documentation for set_size (Jonathan Blandford)
- document IpuzCellCoord (Jonathan Blandford)
- Be quiet, git (Jonathan Blandford)
- removed unused attribute (Jonathan Blandford)
- Add gi-docgen support (Jonathan Blandford)
- Remove deprecated use of build_root() (Jonathan Blandford)
- Make IpuzCharsetBuilder a boxed type and ref counted (Jonathan Blandford)
- Add annotations for gobject-introspection (Jonathan Blandford)
- Add annotations for gobject-introspection (Jonathan Blandford)
- Mark ipuz_puzzle_info_get_unches() as unimplemented (Jonathan Blandford)
- Make IpuzCellStats a boxed type (Jonathan Blandford)
- temporarily annotate get_cells() (Jonathan Blandford)
- Add scope annotation for foreach() (Jonathan Blandford)
- add libubsan explicitly (Jonathan Blandford)
- remove unused quote_str (Jonathan Blandford)
- Use the docs files with gobject-introspection (Jonathan Blandford)
- Initial version of enumeration docs (Jonathan Blandford)
- Split charset into the docs and the header file (Jonathan Blandford)
- Change enumeration to @self to make it more consistent (Jonathan Blandford)
- Add meson_options file (Jonathan Blandford)
- The interesting thing about this file is the docs, not the stubs (Jonathan Blandford)
- New plan: separate docs from headers (Jonathan Blandford)
- Set back ipuz-charset.h file (Jonathan Blandford)
- Copy ipuz-charset.h into stub/ipuz-charset-stub.c (Jonathan Blandford)
- Keep ipuz-charset.h (Jonathan Blandford)
- Include json-glib with our dependencies (Jonathan Blandford)
- Prepare for gobject-introspection (Jonathan Blandford)
- IpuzCharset: clean up doc comments and annotations (Jonathan Blandford)
- Register IpuzCharset as a boxed type (Jonathan Blandford)
- Derive from the glib::Enum type (Jonathan Blandford)
- Enumeration in rust represents IpuzEnumeration in C (Jonathan Blandford)
- try to enable gir generation. (Jonathan Blandford)
- the DELIM macros should be namespaced (Jonathan Blandford)
- Fix doc comments (Jonathan Blandford)
- s/IPuz/Ipuz/g (Jonathan Blandford)
